//
//  modalPopupViewController.m
//  testPractice
//
//  Created by Scott Crouch on 12/2/10.
//  Copyright 2010 Scott Crouch All rights reserved.
//

#import "modalPopupViewController.h"


@implementation modalPopupViewController 

@synthesize tView, staffDetailViewController, model; 

- (void) loadView {  
	
	//so here we create an instance of a UITableView and then we use the function setTView to set the tView global table view to myTableView
	//we then set the delegate and the datasource of the tableview to self 
	UITableView *myTableView = [[UITableView alloc] initWithFrame: CGRectMake(0,0,320,480)]; 
	[self setTView: myTableView];
	[self.tView setDelegate:self];
	[self.tView setDataSource:self];
	
	//now we set the view of this view controller to tView
	[self setView:tView];
	
	//set the title in the nav bar
	[self.navigationItem setTitle: @"Staff List"]; 

	//add a close button to the nav bar which will allow us to dismiss the modal popup view
	UIBarButtonItem *closeButton = [[UIBarButtonItem alloc] initWithTitle:@"Close" style:UIBarButtonItemStyleBordered target:self action:@selector(closePopup:)]; 
	[self.navigationItem setRightBarButtonItem:closeButton];
	model = [[practiceModel alloc] init]; 
	
	//right here we create an instance of a custom view controller that is linked to the table view cells
	staffDetailViewController = [[detailViewController alloc] init]; 

	[closeButton release];
	[myTableView release];

}  
	
- (void) closePopup: (id) sender { 
	
	
	//dismiss the popup
	[self dismissModalViewControllerAnimated:YES]; 

}  





#pragma mark tableView methods


//this function right here determines how many sections you have in your table view, i.e. grouped or plain dividers
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
	
	//return 1 since there is only one section in this table
    return 1;
}


// Customize the number of rows in the table view.
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
	//return the number of tutorials
	return 6;
}


// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
	//here we create a static identifier for a cell
    static NSString *CellIdentifier = @"Cell";
    
	//these next few lines reuses tableview cells if they are not in view anymore so we don't have to load them all
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
    }
    
    //get the index where the cell was clicked
	NSUInteger row = [indexPath row];
	
	//set text of cell to be the string at the index of the cell
	cell.textLabel.text = [self.model getNameAtIndex:row];

	//prints out the name to the debugging console
	NSLog(@"%@", [self.model getNameAtIndex:row]);
	
	//set the cell to have an arrow, so user knows that there is another view when cell is clicked
    [cell setAccessoryType:UITableViewCellAccessoryDisclosureIndicator];
	
	cell.selectionStyle = UITableViewCellSelectionStyleGray;
    
	return cell;
}


- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
	
	//see what row has been clicked
	NSInteger row = [indexPath row];
	
	//prints out row number to debugging console
	NSLog(@"%d", row); 
	
	//if not in detail view
	if (self.staffDetailViewController == nil)
	{
		//set the detail view to the image that corresponds with the clicked cell
		detailViewController *detail = [[detailViewController alloc] init];
		self.staffDetailViewController = detail;
		
		//free the intermediate object
		[detailViewController release];
		staffDetailViewController.model = self.model;
	}
	
	//set title of next view to the cell name
	staffDetailViewController.title = [NSString stringWithFormat:@"%@", [model getNameAtIndex:row]];
	
	//set the index number for for the staff image for the detail view
	[staffDetailViewController setIndexForStaffImage:row];
	
	//push the detail view controller onto the stack
	[self.navigationController pushViewController:staffDetailViewController animated:YES];
	
	//unhighlights the row after it is clicked
	[tableView deselectRowAtIndexPath:indexPath animated:YES];
	
}



- (void) dealloc { 
	
	[tView release];
	[staffDetailViewController release];
	[model release];
	[super dealloc]; 
} 






@end
